@@ -30,6 +30,7 @@
 #include "base/run_loop.h"
 #include "base/task/task_features.h"
 #include "base/time/time.h"
+#include "base/trace_event/trace_event.h"
 #include "build/build_config.h"
 
 using base::android::InputHintChecker;
@@ -85,10 +86,11 @@ NO_INSTRUMENT_STACK_ALIGN int DelayedLooperCallback(int fd,
 // native work below.
 constexpr uint64_t kTryNativeWorkBeforeIdleBit = uint64_t(1) << 32;
 
-std::atomic_bool g_fast_to_sleep = false;
-
 // Implements IOWatcher to allow any MessagePumpAndroid thread to watch
 // arbitrary file descriptors for I/O events.
+// NOTE: When attempting to watch the same `fd` for the same `mode`, this
+// implementation of IOWatcher will unregister the previously registered
+// FdWatch.
 class IOWatcherImpl : public IOWatcher {
  public:
   explicit IOWatcherImpl(ALooper* looper) : looper_(looper) {}
@@ -105,23 +107,41 @@ class IOWatcherImpl : public IOWatcher {
     }
   }
 
-  // IOWatcher:
+  // IOWatcher implementation:
   std::unique_ptr<IOWatcher::FdWatch> WatchFileDescriptorImpl(
       int fd,
       FdWatchDuration duration,
       FdWatchMode mode,
       IOWatcher::FdWatcher& watcher,
       const Location& location) override {
+    const bool is_read =
+        (mode == FdWatchMode::kRead || mode == FdWatchMode::kReadWrite);
+    const bool is_write =
+        (mode == FdWatchMode::kWrite || mode == FdWatchMode::kReadWrite);
+    TRACE_EVENT("base", "MessagePumpAndroid::IOWatcher::WatchFileDescriptor",
+                "fd", fd, "persistent",
+                duration == FdWatchDuration::kPersistent, "write_mode",
+                is_write, "read_mode", is_read);
     auto& watches = watched_fds_[fd];
     auto watch = std::make_unique<FdWatchImpl>(*this, fd, duration, watcher);
-    if (mode == FdWatchMode::kRead || mode == FdWatchMode::kReadWrite) {
-      CHECK(!watches.read_watch) << "Only one watch per FD per condition.";
-      watches.read_watch = watch.get();
-    }
-    if (mode == FdWatchMode::kWrite || mode == FdWatchMode::kReadWrite) {
-      CHECK(!watches.write_watch) << "Only one watch per FD per condition.";
+    if (is_write) {
+      // Detaches the previous FdWatch if there's an attempt to watch the same
+      // `fd` for the same `mode`. This means the previous watch is no longer
+      // responsible for controlling the lifetime of the active FD watch. The
+      // most common case for this happening is multiple EAGAINs in
+      // channel_posix when handling socket/FD writable callbacks.
+      if (watches.write_watch) {
+        watches.write_watch->Detach();
+      }
       watches.write_watch = watch.get();
     }
+    if (is_read) {
+      if (watches.read_watch) {
+        // Analogous to the write scenario.
+        watches.read_watch->Detach();
+      }
+      watches.read_watch = watch.get();
+    }
 
     const int events = (watches.read_watch ? ALOOPER_EVENT_INPUT : 0) |
                        (watches.write_watch ? ALOOPER_EVENT_OUTPUT : 0);
@@ -353,10 +373,6 @@ MessagePumpAndroid::~MessagePumpAndroid() {
   close(delayed_fd_);
 }
 
-void MessagePumpAndroid::InitializeFeatures() {
-  g_fast_to_sleep = base::FeatureList::IsEnabled(kPumpFastToSleepAndroid);
-}
-
 void MessagePumpAndroid::OnDelayedLooperCallback() {
   OnReturnFromLooper();
   // There may be non-Chromium callbacks on the same ALooper which may have left
@@ -485,33 +501,6 @@ void MessagePumpAndroid::DoNonDelayedLooperWork(bool do_idle_work) {
     return;
   }
 
-  // Under the fast to sleep feature, `do_idle_work` is ignored, and the pump
-  // will always "sleep" after finishing all its work items.
-  if (!g_fast_to_sleep) {
-    // Before declaring this loop idle, yield to native work items and arrange
-    // to be called again (unless we're already in that second call).
-    if (!do_idle_work) {
-      ScheduleWorkInternal(/*do_idle_work=*/true);
-      return;
-    }
-
-    // We yielded to native work items already and they didn't generate a
-    // ScheduleWork() request so we can declare idleness. It's possible for a
-    // ScheduleWork() request to come in racily while this method unwinds, this
-    // is fine and will merely result in it being re-invoked shortly after it
-    // returns.
-    // TODO(scheduler-dev): this doesn't account for tasks that don't ever call
-    // SchedulerWork() but still keep the system non-idle (e.g., the Java
-    // Handler API). It would be better to add an API to query the presence of
-    // native tasks instead of relying on yielding once +
-    // kTryNativeWorkBeforeIdleBit.
-    DCHECK(do_idle_work);
-  }
-
-  if (ShouldQuit()) {
-    return;
-  }
-
   // Do the idle work.
   //
   // At this point, the Java Looper might not be idle. It is possible to skip
